Package: tinyimg
Title: Optimize and Compress Images
Version: 0.4
Authors@R: c(
    person("Yihui", "Xie", role = c("aut", "cre", "cph"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666", URL = "https://yihui.org")),
    person("Authors of the dependency Rust crates", role = c("ctb", "cph"), 
      comment = "see AUTHORS file"))
Description: Optimize and compress images using 'Rust' libraries to reduce
    file sizes while maintaining image quality. Supports PNG palette
    reduction and dithering via the 'exoquant' crate before lossless PNG
    optimization via the 'oxipng' crate, and JPEG re-encoding via the
    'mozjpeg' crate. The package provides functions to optimize individual
    image files or entire directories, with configurable compression levels.
    Use tinyimg() as a convenient entry point for mixed PNG/JPEG workflows.
License: MIT + file LICENSE
URL: https://github.com/yihui/tinyimg
BugReports: https://github.com/yihui/tinyimg/issues
SystemRequirements: Cargo (Rust's package manager), rustc
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testit
Config/rextendr/version: 0.3.1
NeedsCompilation: yes
Packaged: 2026-04-14 17:23:37 UTC; yihui
Author: Yihui Xie [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-0645-5666>, URL: https://yihui.org),
  Authors of the dependency Rust crates [ctb, cph] (see AUTHORS file)
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2026-04-14 18:00:03 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 04:38:22 UTC; unix
Archs: tinyimg.so.dSYM
